*********************************************************************************
*Loads and analyzes roads data, to produce the results reported in 
*Table 3 and Appendix Table A8
*********************************************************************************


capture log close
clear
set mem 200000
cd "INSERT DIRECTORY PATH HERE"
log using aej_roads, replace

/* Files used as inputs

	ARp.dbf NUp.dbf CI3p.dbf CO3p.dbf CR3p.dbf EC3p.dbf (all produced by aej_pop00.py)
	dpAR.dbf dpBL.dbf dpBR.dbf dpCA.dbf dpCI.dbf dpCO.dbf dpEC.dbf dpES.dbf dpGT.dbf dpHO.dbf
		 dpMX.dbf dpNU.dbf dpPA.dbf dpPM.dbf dpUS.dbf dpUY.dbfdp VE.dbf (all produced by aej_roads.py)
			BRcensus3.csv
			UScensus3.csv
			VEcensus3.csv  (The admin codes for Brazil, the U.S. and Venezuela that are
					used by the IPUMS income data are too long for
					Arcgis to handle as a zone field. Thus, the python file aej_boundaries.py
					assigns municipality ids to these countries of the form 1,2,... These two
					.csv files merge back in the admin codes used in the income data.)
*/

/* ***---Note: You must download and install the Stata add-on module
	ineqdeco to run this file. Type ssc install ineqdeco from the Stata command
	line or see http://ideas.repec.org/c/boc/bocode/s366002.html
	
	Stephen P. Jenkins, 1999. "INEQDECO: Stata module to calculate inequality indices with 
	decomposition by subgroup,"  Statistical Software Components S366002, Boston College 
	Department of Economics, revised 26 May 2008.
*/


********************************************************
**-----Prepare roads data
********************************************************


***--------Import roads data from dbf files 
foreach X in AR BL BR CI CO CR EC ES GT HO MX NU PA PM US UY VE {
		odbc load VALUE MEAN, table("dp`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		rename mean dp
		gen cntry="`X'"
		label var dp "distance to paved road"
		save dp`X', replace
		clear
}


odbc load CODIGO_DIS MEAN, table("dpPE.dbf") dsn("dBASE Files") lowercase
rename codigo_dis admin3
rename mean dp
gen cntry="PE"
label var dp "distance to paved road"
save dpPE, replace
clear


****------get admin identifiers for Brazil, Venezuela, and U.S.

insheet using BRcensus3.csv
rename cid admin3
mmerge admin3 using dpBR, type(1:1)
drop admin3 _merge
rename  br3codes_a admin3
save dpBR, replace

clear
insheet using UScensus3.csv
rename cid admin3
mmerge admin3 using dpUS, type(1:1)
drop admin3 _merge
rename mun admin3
save dpUS, replace


clear
insheet using VEcensus3.csv
rename cid admin3
mmerge admin3 using dpVE, type(1:1)
drop admin3 _merge
rename ve3codes_c admin3
save dpVE, replace

***---Create separate identifier codes for first and third level administrative units

use dpBL, clear
drop if admin3==0 /*water bodies*/
drop if dp==0 /*water bodies*/
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 1)
gen admin3=substr(temp, 2, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpBL, replace

use dpBR, clear
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 2)
rename temp admin3
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpBR, replace

use dpES, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpES, replace


use dpGT, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpGT, replace


use dpHO, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpHO, replace


use dpMX, clear
replace admin3=admin3+100000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 3)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpMX, replace


use dpPA, clear
drop if admin3<0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
replace admin3=1 if admin1==0 /*Asuncion*/
tab admin1
summ admin3
sort admin1 admin3
save dpPA, replace


use dpPE, clear
destring admin3, replace
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin2=substr(temp, 4, 2)
gen admin3=substr(temp, 6, 2)
drop temp
destring admin1, replace
destring admin2, replace
destring admin3, replace
tab admin1
tab admin2
summ admin3
sort admin1 admin2 admin3
save dpPE, replace


use dpPM, clear
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpPM, replace


use dpUS, clear
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 4)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpUS, replace


use dpUY, clear
drop if admin3==0 /*water bodies*/
rename admin3 admin1
sort admin1
save dpUY, replace


use dpVE, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save dpVE, replace

**************************************************
***---Calculate inequality in proximity to roads
**************************************************

**----Merge municipal-level roads data and population data

foreach X in BL BR ES GT HO MX PA PM US VE {
		use dp`X', clear
		mmerge admin1 admin3 using pop00`X', type(1:1)
		keep if _merge==3
		drop _merge
		egen double total=sum(pop00)
		gen ww=1000*(pop00/total)
		drop total
		sum ww
		sort admin1 admin3
		save dp`X', replace
}


use dpPE, clear
drop if admin1==. /*water body*/
mmerge admin1 admin2 admin3 using pop00PE, type(1:1)
keep if _merge==3
drop _merge
egen double total=sum(pop00)
gen ww=1000*(pop00/total)
drop total
sum ww
sort admin1 admin3
save dpPE, replace

*Recall that this exercise compares roads data at the municipality
*level for all countries (besides Uruguay). Need to get population weights 
*for countries that do not have income data geo-referenced
*to the municipality and hence for which we have not yet calculated municipality
*level population weights. pCI3, pCO3, pCR3, pEC3, pAR, and pNU contain the municipality
*level population data for Chile, Colombia, Costa Rica, Ecuador, Argentina, and Nicaragua.


clear
*Import data on population from dbf files 
foreach X in AR NU CI3 CO3 CR3 EC3 {

		odbc load VALUE SUM, table("`X'p.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		rename sum pop00
		label var pop00 "population (2000)"
		save pop00`X', replace
		clear
}

foreach X in AR NU {
		use dp`X', clear
		mmerge admin3 using pop00`X', type(1:1)
		keep if _merge==3
		drop _merge
		egen double total=sum(pop00)
		gen ww=1000*(pop00/total)
		drop total
		sum ww
		sort admin3
		save dp`X', replace
}

foreach X in CI CO CR EC {
		use dp`X', clear
		mmerge admin3 using pop00`X'3, type(1:1)
		keep if _merge==3
		drop _merge
		egen double total=sum(pop00)
		gen ww=1000*(pop00/total)
		drop total
		sum ww
		sort admin3
		save dp`X', replace
}

foreach X in  UY {
		use dp`X', clear
		mmerge admin1 using pop00`X', type(1:1)
		keep if _merge==3
		drop _merge
		egen double total=sum(pop00)
		gen ww=1000*(pop00/total)
		drop total
		sum ww
		sort admin1
		save dp`X', replace
}

**---Merge files for various countries together
use dpAR.dta, clear
append using dpBL.dta
append using dpBR.dta
append using dpCI.dta
append using dpCO.dta
append using dpCR.dta
append using dpEC.dta
append using dpES.dta
append using dpGT.dta
append using dpHO.dta
append using dpMX.dta
append using dpNU.dta
append using dpPM.dta
append using dpPA.dta
append using dpPE.dta
append using dpUS.dta
append using dpUY.dta
append using dpVE.dta    


keep cntry dp ww pop00
replace dp=dp/1000
bys cntry: summ dp
encode cntry, g(ccnum)
keep if dp<.
save dproad, replace

***------Overall inequality - actual population weights
use dproad, clear
drop ww
egen total=sum (pop00)
gen ww=pop00/total

summ dp [aw=ww]
gen mean_act=r(mean)
gen sd_act=r(sd)

ineqdeco dp [aw=ww], bygroup(ccnum)
gen geb0_act=r(between_ge0)
gen gew0_act=r(within_ge0)
gen get0_act=r(ge0)
gen geb1_act=r(between_ge1)
gen gew1_act=r(within_ge1)
gen get1_act=r(ge1)
gen p90r50r=r(p90p50)
collapse (mean) ge* sd_act mean_act p90* 
save droad_act, replace

***------Overall inequality - equal population weights
use dproad, clear

summ dp [aw=ww]
gen mean_eq=r(mean)
gen sd_eq=r(sd)

ineqdeco dp [aw=ww], bygroup(ccnum)
gen geb0_eq=r(between_ge0)
gen gew0_eq=r(within_ge0)
gen get0_eq=r(ge0)
gen geb1_eq=r(between_ge1)
gen gew1_eq=r(within_ge1)
gen get1_eq=r(ge1)
gen p90r50r=r(p90p50)
collapse (mean) ge* sd_eq mean_eq p90* 
save droad_eq, replace

***------Overall inequality - equal population weights, no U.S.
use dproad, clear
drop if cntry=="US"

summ dp [aw=ww]
gen mean_eqnoUS=r(mean)
gen sd_eqnoUS=r(sd)

ineqdeco dp [aw=ww], bygroup(ccnum)
gen geb0_eqnoUS=r(between_ge0)
gen gew0_eqnoUS=r(within_ge0)
gen get0_eqnoUS=r(ge0)
gen geb1_eqnoUS=r(between_ge1)
gen gew1_eqnoUS=r(within_ge1)
gen get1_eqnoUS=r(ge1)
gen p90r50r=r(p90p50)
collapse (mean) ge* sd_eqnoUS mean_eqnoUS p90* 
save droad_eqnoUS, replace

***-----Within country inequality in proximity to roads, country-by-country

foreach X of num 1/18 {
	 use dproad, clear
	 keep if ccnum==`X'
	 gen id=`X'
   ineqdeco dp [aw=ww]
	 gen get0y=r(ge0)
	 gen get1y=r(ge1)
	 gen p90p50y=r(p90p50)
	 gen p90p10y=r(p90p10)
	 summ dp [aw=ww]
	 gen sd=r(sd)
	 gen mean=r(mean)
	 collapse (mean) ge* sd mean p90* id, by(cntry)
	 save droad_decomp`X', replace
}

use droad_decomp1, clear
foreach X of num 2/18 {
	append using droad_decomp`X'
}
save droad_decomp, replace


********************************************************************************************
***-------------Partial correlations between roads and incomes, controlling for geography,
*--state fixed effects, and demographys
********************************************************************************************

global aejfinalcode = "INSERT DIRECTORY WITH OUTPUT FROM AEJ_YEARN.DO HERE"
cd $aejfinalcode

use yearn_brazil, clear

*--replace income with log income
replace yepcip=ln(yepcip)

*--keep only prime-aged males
keep if male==1
keep if (age>=18 & age<=55)

*--generate a variable for clustering
gen munic=100000*admin1+admin3

*--merge in roads and geographic data
sort admin1 admin3
merge admin1 admin3 using dpBR, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using climBR, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using terrainBR, uniqusing 
tab _merge
drop _merge
tab age, gen(yr)
replace dp=dp/10000 /*make unit of measure 10 km*/
areg yepcip dp, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons replace bdec(3) adds(Clusters, e(N_clust))
mfx, dyex
areg yepcip dp ltem3 lpre3 elev3 slope3 yr*, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(3) adds(Clusters, e(N_clust)) 
mfx, dyex


use yearn_mexico, clear

*--replace income with log income
replace yepcip=ln(yepcip)

*--keep only prime-aged males
keep if male==1
keep if (age>=18 & age<=55)

*--generate a variable for clustering
gen munic=100000*admin1+admin3

*--merge in roads and geographic data
sort admin1 admin3
merge admin1 admin3 using dpMX, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using climMX, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using terrainMX, uniqusing 
tab _merge
drop _merge
tab age, gen(yr)
replace dp=dp/10000 /*make unit of measure 10 km*/

areg yepcip dp, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
areg yepcip dp ltem3 lpre3 elev3 slope3 yr*, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
mfx, dyex



use yearn_panama, clear

*--replace income with log income
replace yepcip=ln(yepcip)

*--keep only prime-aged males
keep if male==1
keep if (age>=18 & age<=55)

*--generate a variable for clustering
gen munic=100000*admin1+admin3

*--merge in roads and geographic data
sort admin1 admin3
merge admin1 admin3 using dpPM, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using climPM, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using terrainPM, uniqusing 
tab _merge
drop _merge
tab age, gen(yr)
replace dp=dp/10000 /*make unit of measure 10 km*/

areg yepcip dp, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
areg yepcip dp ltem3 lpre3 elev3 slope3 yr*, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
mfx, dyex


use yearn_us, clear

*--replace income with log income
replace yepcip=ln(yepcip)

*--keep only prime-aged males
keep if male==1
keep if (age>=18 & age<=55)

*--generate a variable for clustering
gen munic=100000*admin1+admin3

*--merge in roads and geographic data
sort admin1 admin3
merge admin1 admin3 using dpUS, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using climUS, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using terrainUS, uniqusing 
tab _merge
drop _merge
tab age, gen(yr)
replace dp=dp/10000 /*make unit of measure 10 km*/

areg yepcip dp, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
areg yepcip dp ltem3 lpre3 elev3 slope3 yr*, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 



use yearn_venezuela, clear

*--replace income with log income
replace yepcip=ln(yepcip)

*--keep only prime-aged males
keep if male==1
keep if (age>=18 & age<=55)

*--generate a variable for clustering
gen munic=100000*admin1+admin3

*--merge in roads and geographic data
sort admin1 admin3
merge admin1 admin3 using dpVE, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using climVE, uniqusing
tab _merge
drop _merge
sort admin1 admin3
merge admin1 admin3 using terrainVE, uniqusing 
tab _merge
drop _merge
tab age, gen(yr)
replace dp=dp/10000 /*make unit of measure 10 km*/

areg yepcip dp, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 
areg yepcip dp ltem3 lpre3 elev3 slope3 yr*, absorb(admin1) robust cluster(mun)
outreg2 dp using aej_road_corr, tex less(0) nocons append bdec(4) adds(Clusters, e(N_clust)) 



